modbus/modbus.py
changeset 3733 d1acf20e8e7c
parent 2736 a81b72ef156c
child 3750 f62625418bff
--- a/modbus/modbus.py	Wed Sep 28 09:19:07 2022 +0200
+++ b/modbus/modbus.py	Sun Feb 19 08:37:27 2023 +0000
@@ -319,11 +319,19 @@
                 </xsd:restriction>
             </xsd:simpleType>
           </xsd:attribute>
+          <xsd:attribute name="Request_Delay_in_ms" use="optional" default="0">
+            <xsd:simpleType>
+                <xsd:restriction base="xsd:integer">
+                    <xsd:minInclusive value="0"/>
+                    <xsd:maxInclusive value="2147483647"/>
+                </xsd:restriction>
+            </xsd:simpleType>
+          </xsd:attribute>
         </xsd:complexType>
       </xsd:element>
     </xsd:schema>
     """
     # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms
     # corresponds to aprox 25 days.
     CTNChildrenTypes = [("ModbusRequest", _RequestPlug, "Request")]
     # TODO: Replace with CTNType !!!
@@ -565,11 +573,19 @@
                 </xsd:restriction>
             </xsd:simpleType>
           </xsd:attribute>
+          <xsd:attribute name="Request_Delay_in_ms" use="optional" default="0">
+            <xsd:simpleType>
+                <xsd:restriction base="xsd:integer">
+                    <xsd:minInclusive value="0"/>
+                    <xsd:maxInclusive value="2147483647"/>
+                </xsd:restriction>
+            </xsd:simpleType>
+          </xsd:attribute>
         </xsd:complexType>
       </xsd:element>
     </xsd:schema>
     """
     # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms
     # corresponds to aprox 25 days.
     CTNChildrenTypes = [("ModbusRequest", _RequestPlug, "Request")]
     # TODO: Replace with CTNType !!!
@@ -319,11 +319,19 @@
     </xsd:schema>
     """
-    # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms
+    # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms and Request_Delay_in_ms
     # corresponds to aprox 25 days.
     CTNChildrenTypes = [("ModbusRequest", _RequestPlug, "Request")]
@@ -565,11 +573,19 @@
     </xsd:schema>
     """
-    # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms
+    # NOTE: Max value of 2147483647 (i32_max) for Invocation_Rate_in_ms and Request_Delay_in_ms
     # corresponds to aprox 25 days.
     CTNChildrenTypes = [("ModbusRequest", _RequestPlug, "Request")]